pub struct AgentBrowserBackend { /* private fields */ }Expand description
Backend that delegates browser actions to an external agent-browser CLI.
Implementations
Sourceimpl AgentBrowserBackend
impl AgentBrowserBackend
Sourcepub fn new(config: AgentBrowserConfig) -> Self
pub fn new(config: AgentBrowserConfig) -> Self
Create a new backend, checking if the binary is available on PATH.